@@ -29,7 +29,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: L_buffer.c,v 1.11 1997/07/21 02:19:16 pjm Exp $
+ * $Id: L_buffer.c,v 1.13 1997/08/28 00:47:28 pjm Exp $
  */
 
 #include <stdio.h>
@@ -38,9 +38,10 @@
 #include <stdarg.h>
 #include <ctype.h>
 
-#include <I.h>
 #include <L_buffer.h>
 
+#include <nana_error.h>
+
 /*
  * L_buffer_create - malloc's and initialises a buffer with space for 
  *     size bytes worth of messages. Returns NULL on failure.
@@ -52,20 +53,23 @@
  */
 
 L_BUFFER *L_buffer_create(size_t size) { 
-     L_BUFFER *p = malloc(sizeof(L_BUFFER));
-     if(p != NULL) {
-	  p->size = size;
-	  p->data = malloc(size);
-	  p->free = 0;
-	  if(p->data != NULL) {
-	       int i;
-	       for(i = 0; i < size; i++) {
-		    p->data[i] = '\0';
-	       }
-	       return p;
-	  }
-     }
-     return NULL;
+  L_BUFFER *p = malloc(sizeof(L_BUFFER));
+  if(p != 0) {
+    p->size = size;
+    p->data = malloc(size);
+    p->free = 0;
+    if(p->data != 0) {
+      int i;
+      for(i = 0; i < size; i++) {
+	p->data[i] = '\0';
+      }
+      return p;
+    } else {
+      return 0;
+    }
+  } else {
+    return 0;
+  }
 }
 
 /*
@@ -73,10 +77,14 @@ L_BUFFER *L_buffer_create(size_t size) {
  */
   
 inline void L_buffer_putchar(L_BUFFER *b, char c) {
-     b->data[b->free++] = c;
-     if(b->free == b->size) {
-	  b->free = 0;
-     }
+  if(b == 0) {
+    nana_error("L_buffer_putchar: buffer == 0?");
+  }
+
+  b->data[b->free++] = c;
+  if(b->free == b->size) {
+    b->free = 0;
+  }
 }
 
 /*
@@ -84,21 +92,25 @@ inline void L_buffer_putchar(L_BUFFER *b, char c) {
  */
 
 inline void L_buffer_puts(L_BUFFER *b, char *s) {
-     int i;
+  int i;
 
-     /* map NULL pointer to "(null)" - suggested by Phil Blecker */
-     if(s == (char *) 0) {
-          s = "(null)";
-     }
+  if(b == 0) {
+    nana_error("L_buffer_puts: buffer == 0");
+  }
 
-     /* just copy into the buffer with wraparound */
-     for(i = 0; s[i] != '\0'; i++) {
-	  b->data[b->free] = s[i];
-	  b->free++;
-	  if(b->free == b->size) {
-	       b->free = 0;
-	  }
-     }
+  /* map 0 pointer to "(null)" - suggested by Phil Blecker */
+  if(s == (char *) 0) {
+    s = "(null)";
+  }
+
+  /* just copy into the buffer with wraparound */
+  for(i = 0; s[i] != '\0'; i++) {
+    b->data[b->free] = s[i];
+    b->free++;
+    if(b->free == b->size) {
+      b->free = 0;
+    }
+  }
 }
 
 
@@ -113,27 +125,29 @@ inline void L_buffer_puts(L_BUFFER *b, char *s) {
 
 void L_buffer_printf(L_BUFFER *b, const char *format, ...) {
 
-     char buffer[512]; 
-     int n;
-     va_list ap;
+  char buffer[512]; 
+  int n;
+  va_list ap;
      
 
-     I(b != NULL);
+  if(b == 0) {
+    nana_error("L_buffer_printf: buffer == 0?");
+  }
 
-     /* printf the arguments into buffer[0...] */
-     va_start(ap, format); 
+  /* printf the arguments into buffer[0...] */
+  va_start(ap, format); 
 #if HAVE_VSNPRINTF == 1
-     n = vsnprintf(&buffer[0], sizeof(buffer), format, ap);
+  n = vsnprintf(&buffer[0], sizeof(buffer), format, ap);
 #elif HAVE_VSPRINTF == 1
-     n = vsprintf(&buffer[0], format, ap);
+  n = vsprintf(&buffer[0], format, ap);
 #else
 #error We need either vsprintf or vsnprintf for this one
-       Sorry perhaps you should install libiberty
+  Sorry perhaps you should install libiberty;
 #endif
 
-     va_end(ap);
+  va_end(ap);
 
-     L_buffer_puts(b, &buffer[0]);
+  L_buffer_puts(b, &buffer[0]);
 }
 
 /*
@@ -142,43 +156,45 @@ void L_buffer_printf(L_BUFFER *b, const char *format, ...) {
  */
 
 void L_buffer_dump(L_BUFFER *b, FILE *fp) {
-     int i;
-     char c;
+  int i;
+  char c;
 
-     I(b != NULL);
+  if(b == 0) {
+    nana_error("L_buffer_dump: buffer == 0?");
+  }
 
-     /* print the banner */
-     fprintf(fp, "* L_buffer_dump =\n");
+  /* print the banner */
+  fprintf(fp, "* L_buffer_dump =\n");
 
-     /* skip '\0' bytes from free upwards to find the oldest message */
-     for(i = b->free+1; ; i++) { 
-	  if(i == b->size) { /* wraparound at end of buffer */ 
-	       i = 0;
-	  }
-	  if(i == b->free) { /* been through the entire buffer of '\0' */
-	       fprintf(fp, "buffer was empty\n");
-	       goto end;
-	  }
-	  if(b->data[i] != '\0') { /* found oldest one */
-	       break;
-	  }
-     }
+  /* skip '\0' bytes from free upwards to find the oldest message */
+  for(i = b->free+1; ; i++) { 
+    if(i == b->size) { /* wraparound at end of buffer */ 
+      i = 0;
+    }
+    if(i == b->free) { /* been through the entire buffer of '\0' */
+      fprintf(fp, "buffer was empty\n");
+      goto end;
+    }
+    if(b->data[i] != '\0') { /* found oldest one */
+      break;
+    }
+  }
 
-     /* now print out in time order */
-     do {
-	  c = b->data[i];
-	  if(isprint(c) || isspace(c)) {
-	       fputc(c, fp);
-	  } else { /* can't be printed so print it in hex */
-	       fprintf(fp, "* non-printable character 0x%x\n", c);
-	  }
-	  i++;
-	  if(i == b->size) {
-	       i = 0;
-	  }
-     } while(b->data[i] != '\0' && i != b->free);
+  /* now print out in time order */
+  do {
+    c = b->data[i];
+    if(isprint(c) || isspace(c)) {
+      fputc(c, fp);
+    } else { /* can't be printed so print it in hex */
+      fprintf(fp, "* non-printable character 0x%x\n", c);
+    }
+    i++;
+    if(i == b->size) {
+      i = 0;
+    }
+  } while(b->data[i] != '\0' && i != b->free);
 end:     
-     fprintf(fp, "* end of dump\n");
+  fprintf(fp, "* end of dump\n");
 }
 
 /*
@@ -186,13 +202,16 @@ end:
  */
 
 void L_buffer_clear(L_BUFFER *b) {
-     int i;
+  int i;
 
-     I(b != NULL);
-     for(i = 0; i < b->size; i++) {
-	  b->data[i] = '\0';
-     }
-     b->free = 0;
+  if(b == 0) {
+    nana_error("L_buffer_clear: buffer == 0?");
+  }
+
+  for(i = 0; i < b->size; i++) {
+    b->data[i] = '\0';
+  }
+  b->free = 0;
 }
 
 /*
@@ -200,9 +219,11 @@ void L_buffer_clear(L_BUFFER *b) {
  */
 
 void L_buffer_delete(L_BUFFER *b) {
-     if(b != NULL) {
-	  free(b->data);
-	  free(b);
-     }
+  if(b != 0) {
+    if(b->data != 0) {
+      free(b->data);
+    }
+    free(b);
+  }
 }
 
