@@ -25,7 +25,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: L_buffer.h,v 1.3 1997/07/21 02:19:17 pjm Exp $
+ * $Id: L_buffer.h,v 1.4 1997/08/28 00:47:29 pjm Exp $
  */
 
 
@@ -78,7 +78,12 @@ typedef struct {
 
 L_BUFFER *L_buffer_create(size_t size);
 
+#ifdef __GNUC__
+void L_buffer_printf(L_BUFFER *b, const char *format, ...) 
+  __attribute__((format (printf, 2, 3)));
+#else
 void L_buffer_printf(L_BUFFER *b, const char *format, ...);
+#endif
 
 void L_buffer_puts(L_BUFFER *b, char *str);
 
